This function will add the necessary information to omicsData such that survival analysis can be applied to it.
surv_designation(
omicsData,
t_death,
t_progress = NULL,
ind_death,
ind_progress = NULL,
covariates = NULL
)omicsData is returned with the additional attribute
an object of the class 'lipidData', 'metabData', 'pepData',
or 'proData' usually created by as.lipidData,
as.metabData, as.pepData, or
as.proData, respectively.
the column in 'f_data' that corresponds to the subjects' time of death
the column in 'f_data' that corresponds to the subjects' time of progression
the column in 'f_data' that corresponds to the subjects' status, e.g. alive/dead
the column in 'f_data' that corresponds to the subjects' progression status
the column(s) in 'f_data' that correspond to covariates to be included in the survivial analysis
Bryan Stanfill